!//////////////////////////////////////////////////////////////////////////
	subroutine elmtfp(lelfp)
!     ELastic element MaTrix of FP
!//////////////////////////////////////////////////////////////////////////
      include 'param.h'
      include 'comst.h'
!
      dimension elcod(3,4),shapf(6),deriv(2,6),cartd(2,6)
      dimension bmatx(3,8),gmatx(3,4),dmatx(3,3)
      dimension hmatx(2,8),hhmat(8,8)
      dimension stfuu(8,8),stfua(8,4),stfau(4,8),stfaa(4,4)
      dimension emass(nval0,nval0)
!
!	-- initialize element stiffness matrix and mass matrix
!
!              stfuu : submatrix of STiFness UU
!              estfp : Element STiffness matrix of Fem Plate
!              emass : Element MASS matrix (consistent mass)
!              emsfp : Element MaSs matrix of Fem Plate (lumped mass)   
      do ivafp=1,nvafp
      do jvafp=1,nvafp
      stfuu(ivafp,jvafp) = 0.
      estfp(ivafp,jvafp,lelfp) = 0.
      emass(ivafp,jvafp) = 0.
      emsfp(ivafp,jvafp,lelfp) = 0.
      enddo
      enddo
!              stfua : submatrix of STiFness UA
!              stfau : submatrix of STiFness AU
      do ivafp=1,nvafp
      do jcomp=1,ncomp
      stfua(ivafp,jcomp) = 0.
      stfau(jcomp,ivafp) = 0.
      enddo
      enddo
!              stfaa : submatrix of STiFness AA
      do icomp=1,ncomp
      do jcomp=1,ncomp
      stfaa(icomp,jcomp) = 0.
      enddo
      enddo
!
!	-- evaluate the coordinates of the element nodal points
!              elcod : ELement COorDinate
      do ipoin=1,4
      inod = nodfp(ipoin,lelfp)
      do idime=1,ndime
      elcod(idime,ipoin) = coord(idime,inod)
      enddo
      enddo
!
!     elastic properties
!           thick : THICKness
!			young : YOUNG's modulus
!			poiss : POISSon ratio
!           dnsty : DeNSiTY
      nmt = matfp(lelfp)
      thick = profp(1,nmt)
      young = profp(2,nmt)
      poiss = profp(3,nmt)
!     dnsty (kg/m3) --> dnsty*10-9 (kg/mm3)
      dnsty = profp(4,nmt)/10.0**9
!
!	-- enter loop for each gauss point
      kgaus = 0
      do igaus=1,ngaus
      do jgaus=1,ngaus
      kgaus = kgaus+1
      ri = posgp(igaus)
      sj = posgp(jgaus)
!
!	- evaluate shape fuction and Jacobian matrix
!	==================================================
      call shapfp( ri, sj, shapf, deriv )
      call jacofp( djacb, cartd, elcod, deriv )
!	==================================================
!
!	- evaulate [B] and [G] matrices
!	====================================================
      call bgdmfp( bmatx, gmatx, dmatx, cartd, kgaus, lelfp )
!	====================================================
!
!	- evaulate [H] and [H]T[H] matrices
!	=====================================
      call hmatfp( shapf, hmatx, hhmat )
!	=====================================
!
!	- calculate element mass matrix
!     save scalor value for integration
      twwdj(kgaus,lelfp) = thick*weigp(igaus)*weigp(jgaus)*djacb
      dvalu = twwdj(kgaus,lelfp)
      do ivafp=1,nvafp
      do jvafp=1,nvafp
      emass(ivafp,jvafp) = emass(ivafp,jvafp) +&
     	hhmat(ivafp,ivafp)*dnsty*dvalu
      enddo
      enddo
!
!	- calculate element gravity force vector
!     N = kgm/sec2
      do ivafp=1,nvafp
      egfrc(ivafp,lelfp) = egfrc(ivafp,lelfp) +&
        hmatx(2,ivafp)*(-dnsty*grvty)*dvalu
      enddo
!
!	- calculate element stiffness matrix
!	==============================================
      call elstfp( bmatx, gmatx, dmatx,&
      stfuu, stfua, stfau, stfaa, dvalu )
!	==============================================
!     [D]
      do istfp=1,nstfp
      do jstfp=1,nstfp
      dmtfp(istfp,jstfp,kgaus,lelfp) = dmatx(istfp,jstfp)
      enddo
      enddo
!
      enddo
      enddo
!
!   - removing incompatible mode
!	======================================================
      call incomp( stfuu, stfua, stfau, stfaa, lelfp )
!	======================================================
!
!   - lumped mass matrix
      do ivafp=1,nvafp
      esum = 0.
      do jvafp=1,nvafp
      esum = esum + emass(ivafp,jvafp)
      enddo
      emsfp(ivafp,ivafp,lelfp) = esum
      enddo
!
      return
      end
!
