! =======================================================
      subroutine ldinv(a, n, n1, eps, d, w, wk, ier)
! =======================================================
!
!***********************************************************************
!*  inversion of a symmetric matrix on modified cholesky method.       *
!*                                                                     *
!*  parameters:                                                        *
!*   on entry:                                                         *
!*     a      the array with dimendion a(n1,n) which contains          *
!*            upper triangular part of the matrix a.                   *
!*     n      the order of the matrix a.                               *
!*     n1     the leading dimension of the array a.                    *
!*     eps    the tolerance for pivotal elements.                      *
!*   on return:                                                        *
!*     a      the upper triangular matrix u, and the inverse matrix    *
!*            in lower triangular part.                                *
!*     d      the inverse of diagonal elements of lower triangular     *
!*            matrix l.                                                *
!*     ier    the error code. if ier=0, normal return.                 *
!*   others:  working parameters.                                      *
!*                                                                     *
!*  copyright:     thutomu oguni     sep. 1 1991       ver. 1          *
!***********************************************************************
!
      implicit real*8(a-h,o-z)
!
      dimension a(n1,n), d(n), w(n), wk(n)
!
!
!  decomposition
      if (n1 .lt. n) then
      ier = 2
      write(*,*) '(subr. ldinv) invalid argument.', n, n1
      return
      endif
      d(1) = 1.0 / a(1,1)
      do 40 j=2,n
      if (j .ne. 2) then
      do 20 i=2,j-1
      s = 0.0
      do 10 k=1,i-1
   10 s = s + a(k,i) * a(k,j)
   20 a(i,j) = a(i,j) - s
      endif
      s = 0.0
      do 30 i=1,j-1
      t = a(i,j)
      a(i,j) = d(i) * t
   30 s = s + a(i,j) * t
      t = a(j,j) - s
      if (abs(t) .le. eps) then
      write(*,*) '(subr. ldinv) singular at step = ', j
      ier = 1
      return
      endif
      d(j) = 1.0 / t
   40 a(j,j) = t
!  a(j,j) = diagonal element of matrix d
!  calculation of lower parts of inverse (c(j,k))
      do 100 k=n,1,-1
      s = 0.0
      if (k .ne. n) then
      do 50 i=k+1,n
   50 w(i) = a(k,i)
      do 80 j=k+1,n
      s = 0.0
      do 60 i=k+1,j
   60 s = s + w(i) * a(j,i)
      if (j .ne. n) then
      do 70 i=j+1,n
   70 s = s + w(i) * a(i,j)
      endif
      wk(j) = - s
      a(j,k) = wk(j)
   80 continue
!  calculation of diagonals (c(k,k))
      s = 0.0
      do 90 i=k+1,n
   90 s = s + wk(i) * w(i)
      endif
      a(k,k) = d(k) - s
  100 continue
      ier = 0
      return
!  end of ldinv
      end
