!***********************************************************************
	SUBROUTINE SSPACE( A, B, MAXA, EIGV, EIG, N0, NC0,&
        NN, NNM, NWK, NWM, NROOT, NC, NNC, NITEM, IFSS )
!
!-------------------------------------------------------------------------------------------------------
!	PROGRAM
!	TO SOLVE FOR THE SMALLEST EIGENVALUES AND CORRESPONDING 
!	EIGENVECTORS IN THE GENERALIZED EIGENPROBLEM USING THE 
!	SUBSPACE ITERATION METHOD
!
!  ---	INPUT VALIABLES
!	A(NWK) 		= STIFFNESS MATRIX IN COMPACTED FORM (ASSUMED 
!				  POSITIVE DEFINITE)
!	B(NWM) 		= MASS MATRIX IN COMPACTED FORM
!	MAXA(NNM) 	= VECTOR CONTAINING ADDRESSED OF DIAGONAL 
!				  ELEMENTS OF STIFFNESS MATRIX A
!	R(NN,NC)	= EIGENVECTORS IN SOLUTION EXIT --> EIGV(N0,NC0)
!	EIG(NC) 	= EIGENVALUES ON SOLUTION EXIT
!	TT(NN) 		= WORKING VECTOR
!	W(NN) 		= WORKING VECTOR
!	AR(NNC) 	= WORKING VECTOR STORING PROJECTION OF K
!	BR(NNC) 	= WORKING VECTOR STORING PROJECTION OF M
!	VEC(NC,NC) 	= WORKING VECTOR
!	D(NC) 		= WORKING VECTOR
!	RTOLV(NC) 	= WORKING VECTOR
!	BUP(NC) 	= WORKING VECTOR
!	BLO(NC) 	= WORKING VECTOR
!	BUPC(NC) 	= WORKING VECTOR
!	NN 			= ORDER OF STIFFNESS AND MASS MATRICES
!	NNM 		= NN + 1
!	NWK 		= NUMBER OF ELEMENTS BELOW SKYLINE OF 
!				  STIFFNESS MATRIX
!	NWM 		= NUMBER OF ELEMENTS BELOW SKYLINE OF 
!				  MASS MATRIX
!				  I.E.	NWM = NWK   FOR CONSISTENT MASS MATRIX
!		   				NWM = NN    FOR LUMPED MASS MATRIX
!	NROOT 		= NUMBER OF REQUIRED EIGENVALUES AND EIGENVECTORS
!	RTOL 		= CONVERGENCE TOLERANCE ON EIGENVALUES
!					( 1.E-06 OR SMALLER)
!	NC 			= NUMBER OF ITERATION VECTORS USED 
!				  (USUALLY SET TO MIN(2*NROOT, NROOT+8), BUT NC 
!				   CANNOT BE LARGER THAN THE NUMBER OF MASS 
!				   DEGREES OF FREEDOM)
!	NNC 		= NC*(NC+1)/2 DIMENSION OF STORAGE VECTORS AR, BR
!	NITEM 		= MAXIMUM NUMBER OF SUBSPACE ITERATIONS PERMITTED
!				  (USUALLY SET TO 16)
!				  THE PARAMETERS NC AND/OR NITEM MUST BE 
!				  INCREASED IF A SOLUTION HAS NOT CONVERGED
!	IFSS 		= FLAG FOR STURM SEQUENCE CHECK
!					EQ.0	NO CHECK
!					EQ.1	CHECK
!	NSTIF 		= SCRATCH FILE TO STORE STIFFNESS MATRIX
!
!  ---	OUTPUT
!	EIG(NROOT) = EIGENVALUES
!	R(NN,NROOT) = EIGENVECTORS
!
!---------------------------------------------------------------------------
	IMPLICIT REAL*8 ( A-H, O-Z )
	INTEGER MAXA(NNM)
	DIMENSION A(NWK), B(NWM), EIGV(N0,NC0), R(NN,NC), EIG(NC),&
     	TT(NN), W(NN), D(NC), VEC(NC,NC), AR(NNC), BR(NNC),&
     	RTOLV(NC), BUP(NC), BLO(NC), BUPC(NC)
!
!---------------------------------------------------------------------------
!	SET TOLERANCE FOR JACOBI ITERATION
	TOLJ = 0.000000000001
!
!	INITIALIZATION
!
	ICONV = 0
	NSCH = 0
	NSMAX = 12
	N1 = NC + 1
	NC1 = NC - 1
!	REWIND NSTIF
!	WRITE( NSTIF) A
	DO 60 I=1,NC
60	D(I) = 0.
!
!	ESTABLISH STARTING ITERATION VECTORS
!
	ND = NN / NC
	IF ( NWM.GT.NN ) GO TO 4
	J = 0
	DO 2 I=1,NN
	II = MAXA(I)
	R(I,1) = B(I)
	IF( B(I).GT.0. ) J = J + 1
2	W(I) = B(I) / A(II)
	IF ( NC.LE.J ) GO TO 16
	RETURN
4	DO 10 I=1,NN
	II = MAXA(I)
	R(I,1) = B(II)
10	W(I) = B(II) / A(II)
16	DO 20 J=2,NC
	DO 20 I=1,NN
20	R(I,J) = 0.
!
	L = NN-ND
	DO 30 J=2,NC
	RT = 0.
	DO 40 I=1,L
	IF( W(I).LT.RT ) GO TO 40
	RT = W(I)
	IJ = I
40	CONTINUE
	DO 50 I=L,NN
	IF( W(I).LE.RT ) GO TO 50
	RT = W(I)
	IJ = I
50	CONTINUE
	TT(J) = FLOAT(IJ)
	W(IJ) = 0.
	L = L - ND
30	R(IJ,J) = 1.
!
!	FACTORIZE MARIX A INTO (L) * (D) * (L(T))
!
	ISH = 0
	CALL DECOMP ( A, MAXA, NN, ISH )
!
! ---	START OF ITERATION LOOP
!
	NITE = 0
100	NITE = NITE + 1
!
!	CALCULATE THE PROJECTIONS OF A AND B
!
90	IJ = 0
	DO 110 J=1,NC
	DO 120 K=1,NN
120	TT(K) = R(K,J)
	CALL REDBAK ( A, TT, MAXA, NN )
	DO 130 I=J,NC
	ART = 0.
	DO 140 K=1,NN
140	ART = ART + R(K,I) * TT(K)
	IJ = IJ + 1
130	AR(IJ) = ART
	DO 150 K=1,NN
150	R(K,J) = TT(K)
110	CONTINUE
	IJ = 0
	DO 160 J=1,NC
	CALL MULT ( TT, B, R(1,J), MAXA, NN, NWM )
	DO 180 I=J,NC
	BRT = 0.
	DO 190 K=1,NN
190	BRT = BRT + R(K,I) * TT(K)
	IJ = IJ + 1
180	BR(IJ) = BRT
	IF( ICONV.GT.0 ) GO TO 160
	DO 200 K=1,NN
200	R(K,J) = TT(K)
160	CONTINUE
!
!	SOLVE FOR EIGENSYSTEM OF SUBSPACE OPERATORS
!
320	CALL JACOBI ( AR, BR, VEC, EIG, W, NC, NNC,&
     	TOLJ, NSMAX )
!
!	ARRANGE EIGENVALUES IN ASCENDING ORDER
!
350	IS = 0
	II = 1
	DO 360 I=1,NC1
	ITEMP = II + N1 -I
	IF ( EIG(I+1).GE.EIG(I) ) GO TO 360
	IS = IS + 1
	EIGT = EIG(I+1)
	EIG(I+1) = EIG(I)
	EIG(I) = EIGT
	BT = BR(ITEMP)
	BR(ITEMP) = BR(II)
	BR(II) = BT
	DO 370 K=1,NC
	RT = VEC(K,I+1)
	VEC(K,I+1) = VEC(K,I)
370	VEC(K,I) = RT
360	II = ITEMP
	IF ( IS.GT.0 ) GO TO 350
!
!	CALCULATE B TIMES APPROXIMATE EIGENVECTORS ( ICONV.EQ.0 )
!	OR FINAL EIGENVECTOR APPROXIMATIONS ( ICONV.GT.0 )
!
375	DO 420 I=1,NN
	DO 422 J=1,NC
422	TT(J) = R(I,J)
	DO 424 K=1,NC
	RT = 0.
	DO 430 L=1,NC
430	RT = RT + TT(L) * VEC(L,K)
424	R(I,K) = RT
420	CONTINUE
	IF ( ICONV.GT.0 ) GO TO 500
!
!	CHECK FOR CONVERGENCE OF EIGENVALUES
!
	DO 380 I=1,NC
	DIF = ABS( EIG(I) - D(I) )
380	RTOLV(I) = DIF / EIG(I)
!
385	DO 390 I=1,NROOT
	IF ( RTOLV(I) .GT. RTOL ) GO TO 400
390	CONTINUE
	ICONV = 1
	GO TO 100
400	IF ( NITE .LT. NITEM ) GO TO 410
	ICONV = 2
	IFSS = 0
	GO TO 100
!
410	DO 440 I=1,NC
440	D(I) = EIG(I)
	GO TO 100
!
! ---	END OF ITERATION LOOP
!
500	CONTINUE
	DO 530 K=1,NN
530	CONTINUE
!
! --- SAVE EIGENVECTOR R(NN,NC) INTO EIGV(N0,NC0)
	DO 540 I=1,N0
	DO 540 J=1,NC0
540	EIGV(I,J) = 0.
	DO 550 I=1,NN
	DO 550 J=1,NC
550	EIGV(I,J) = R(I,J)
!
!	CALCULATE AND PRINT ERROR NORMS
!
!	REWIND NSTIF
!	READ(NSTIF) A
!
	DO 580 L=1,NROOT
	RT = EIG(L)
	CALL MULT ( TT, A, R(1,L), MAXA, NN, NWK )
	VNORM = 0.
	DO 590 I=1,NN
590	VNORM = VNORM + TT(I) * TT(I)
	CALL MULT ( W, B, R(1,L), MAXA, NN, NWM )
	WNORM = 0.
	DO 600 I=1,NN
	TT(I) = TT(I) - RT * W(I)
600	WNORM = WNORM + TT(I) * TT(I)
	VNORM = SQRT ( VNORM )
	WNORM = SQRT ( WNORM )
	D(L) = WNORM / VNORM
580	CONTINUE
!
!	APPLY STURM SEQUENCE CHECK
!
	IF ( IFSS.EQ.0 ) GO TO 700
	CALL SCHECK ( EIG, RTOLV, BUP, BLO, BUPC, NC,&
     	NEI, RTOL, SHIFT )
!
!	SHIFT MATRIX A
!
!	REWIND NSTIF
!	READ ( NSTIF ) A
	IF ( NWM .GT. NN ) GO TO 645
	DO 640 I=1,NN
	II = MAXA(I)
640	A(II) = A(II) - B(I) * SHIFT
	GO TO 660
645	DO 650 I=1,NWK
650	A(I) = A(I) - B(I) * SHIFT
!
!	FACTORIZE SHIFTED MATRIX
!
660	ISH = 1
	CALL DECOMP ( A, MAXA, NN, ISH )
!
!	COUNT NUMBER OF NEGATIVE DIAGONAL ELEMENTS
!
	NSCH = 0
	DO 664 I=1,NN
	II = MAXA(I)
	IF ( A(II) .LT. 0. ) NSCH = NSCH + 1
664	CONTINUE
	IF ( NSCH .EQ. NEI ) GO TO 670
	NMIS = NSCH - NEI
	GO TO 700
670	CONTINUE
700	RETURN
!
	END
!
	SUBROUTINE DECOMP ( A, MAXA, NN, ISH )
!----------------------------------------------------------------------------
!	PROGRAM
!	TO CALCULATE (L) * (D) * (L)T FACTORIZATION OF
!	STIFFNESS MATRIX
!----------------------------------------------------------------------------
	IMPLICIT REAL*8 ( A-H, O-Z )
	DIMENSION A(1), MAXA(1)
	IF ( NN .EQ. 1 ) RETURN
!
	DO 200 N=1,NN
	KN = MAXA( N )
	KL = KN + 1
	KU = MAXA ( N+1 ) - 1
	KH = KU - KL
	IF ( KH ) 304, 240, 210
210	K = N - KH
	IC = 0
	KLT = KU
	DO 260 J=1,KH
	IC = IC + 1
	KLT = KLT - 1
	KI = MAXA( K )
	ND = MAXA( K+1 ) - KI - 1
	IF ( ND ) 260, 260, 270
270	KK = MIN0( IC, ND )
	C = 0.
	DO 280 L=1,KK
280	C = C + A( KI + L ) * A( KLT + L )
	A( KLT ) = A( KLT ) - C
260	K = K + 1
240	K = N
	B = 0.
	DO 300 KK = KL, KU
	K = K - 1
	KI = MAXA( K )
	C = A( KK ) / A( KI )
	IF ( ABS( C ) .LT. 1.E07 ) GO TO 290
	RETURN
290	B = B + C * A( KK )
300	A( KK ) = C
	A( KN ) = A( KN ) - B
304	IF ( A( KN) ) 310, 310, 200
310	IF ( ISH .EQ. 0 ) GO TO 320
	IF ( A( KN ) .EQ. 0. ) A( KN ) = -1.E-16
	GO TO 200
320	CONTINUE
	RETURN
200	CONTINUE
!
	RETURN
	END
!
	SUBROUTINE REDBAK ( A, V, MAXA, NN )
!---------------------------------------------------------------------------------
!	PROGRAM
!	TO REDUCE AND BACK-SUBSTITUTE ITERATION VECTORS
!---------------------------------------------------------------------------------
	IMPLICIT REAL*8 ( A-H, O-Z )
	DIMENSION A(1), V(1), MAXA(1)
!
	DO 400 N=1,NN
	KL = MAXA( N ) + 1
	KU = MAXA( N+1 ) - 1
	IF ( KU - KL ) 400, 410, 410
410	K = N
	C = 0.
	DO 420 KK = KL, KU
	K = K - 1
420	C = C + A( KK ) * V( K )
	V( N ) = V( N ) - C
400	CONTINUE
!
	DO 480 N = 1, NN
	K = MAXA( N )
480	V( N ) = V( N ) / A( K )
	IF ( NN.EQ.1 ) RETURN
	N = NN
	DO 500 L=2,NN
	KL = MAXA( N ) + 1
	KU = MAXA( N+1 ) - 1
	IF ( KU - KL ) 500, 510, 510
510	K = N
	DO 520 KK = KL, KU
	K = K - 1
520	V( K ) = V( K ) - A( KK ) * V( N )
500	N = N - 1
!
	RETURN
	END
!
	SUBROUTINE MULT ( TT, B, RR, MAXA, NN, NWM )
!--------------------------------------------------------------------------
!	PROGRAM
!	TO EVALUATE PRODUCT OF B TIMES RR AND STORE RESULT IN TT
!--------------------------------------------------------------------------
	IMPLICIT REAL*8 ( A-H, O-Z )
	DIMENSION TT(1), B(1), RR(1), MAXA(1)
!
	IF ( NWM .GT. NN ) GO TO 20
	DO 10 I=1,NN
10	TT( I ) = B( I ) * RR( I )
	RETURN
!
20	DO 40 I=1,NN
40	TT( I ) = 0.
	DO 100 I=1,NN
	KL = MAXA( I )
	KU = MAXA( I+1 ) - 1
	II = I + 1
	CC = RR( I )
	DO 100 KK=KL,KU
	II = II -1
100	TT( II ) = TT( II ) + B( KK ) * CC
	IF ( NN .EQ. 1 ) RETURN
	DO 200 I=2,NN
	KL = MAXA( I ) + 1
	KU = MAXA( I+1 ) - 1
	IF ( KU - KL ) 200, 210, 210
210	II = I
	AA = 0.
	DO 220 KK = KL, KU
	II = II - 1
220	AA = AA + B( KK ) * RR( II )
	TT( I ) = TT( I ) + AA
200	CONTINUE
!
	RETURN
	END
!
	SUBROUTINE SCHECK ( EIG, RTOLV, BUP, BLO, BUPC, NC,&
     	NEI, RTOL, SHIFT )
!-------------------------------------------------------------------------------
!	PROGRAM
!	TO EVALUATE SHIFT FOR STURM SEQUENCE CHECK
!-------------------------------------------------------------------------------
	IMPLICIT REAL*8 ( A-H, O-Z )
	DIMENSION EIG( NC ), RTOLV( NC ) , BUP( NC ), BLO( NC ),&
     	BUPC( NC ), NEIV( NC )
!
	FTOL = 0.01
!
	DO 100 I=1,NC
	BUP( I ) = EIG( I ) * ( 1. + FTOL )
100	BLO( I ) = EIG( I ) * ( 1. - FTOL )
	NROOT = 0
	DO 120 I=1,NC
120	IF ( RTOLV( I ) .LT. RTOL ) NROOT = NROOT + 1
	IF ( NROOT .GE. 1 ) GO TO 200
	RETURN
!
!	FIND UPPER BOUNDS ON EIGENVALUE CLUSTERS
!
200	DO 240 I=1,NROOT
240	NEIV( I ) = 1
	IF ( NROOT .NE. 1 ) GO TO 260
	BUPC( 1 ) = BUP( 1 )
	LM = 1
	L = 1
	I = 2
	GO TO 295
260	L = 1
	I = 2
270	IF ( BUP( I-1 ) .LE. BLO( I ) ) GO TO 280
	NEIV( L ) = NEIV( L ) + 1
	I = I + 1
	IF ( I .LE. NROOT ) GO TO 270
280	BUPC( L ) = BUP( I-1 )
	IF ( I .GT. NROOT ) GO TO 290
	L = L + 1
	I = I + 1
	IF ( I .LE. NROOT ) GO TO 270
	BUPC( L ) = BUP( I-1 )
290	LM = L
	IF ( NROOT .EQ. NC ) GO TO 300
295	IF ( BUP( I-1 ) .LE. BLO( I ) ) GO TO 300
	IF ( RTOLV( I ) .GT. RTOL ) GO TO 300
	BUPC( L ) = BUP( I )
	NEIV( L ) = NEIV( L ) + 1
	NROOT = NROOT + 1
	IF ( NROOT .EQ. NC ) GO TO 300
	I = I + 1
	GO TO 295
!
!	FIND SHIFT
!
300	CONTINUE
	LL = LM -1
	IF ( LM .EQ. 1 ) GO TO 310
330	DO 320 I=1,LL
320	NEIV( L ) = NEIV( L ) + NEIV( I )
	L = L - 1
	LL = LL - 1
	IF ( L .NE. 1 ) GO TO 330
310	CONTINUE
	L = 0
	DO 340 I=1,LM
	L = L + 1
	IF ( NEIV(I) .GE. NROOT ) GO TO 350
340	CONTINUE
350	SHIFT = BUPC( L )
	NEI = NEIV( L )
!
	RETURN
!
!1005	FORMAT ( / 6E22.14 )
!1006	FORMAT ( / 6I22 )
!1010	FORMAT ( '*** ERROR   SOLUTION STOP IN * SCHECK * '/ 12X,
!     1	'NO EIGENVALUES FOUND.' / 1X )
!1020	FORMAT ( /// 'UPPER BOUNDS ON EIGENVALUE CLUSTERS' )
!1030	FORMAT ( 'NO OF EIGENVALUES IN EACH CLUSTERS' )
!1040	FORMAT ( 'NO OF EIGENVALUES LESS THAN UPPER BOUNDS' )
	END
!
	SUBROUTINE JACOBI ( A, B, X, EIG, D, N, NWA,&
     	RTOL, NSMAX )
!	---------------------------------------------------------------------
!	PROGRAM
!	TO SOLVE THE GENERALIZED EIGENPROBLEM USING THE
!	GENERALIZED JACOBI ITERATION
!	---------------------------------------------------------------------
	IMPLICIT REAL*8 ( A-H, O-Z )
	DIMENSION A( NWA ), B( NWA ), X( N, N ), EIG( N ), D( N )
!
!	INITIALIZE EIGENVALUE AND EIGENVECTOR MATRICES
!
	N1 = N + 1
	II = 1
	DO 10 I=1,N
	IF ( A(II) .GT. 0. .AND. B(II) .GT. 0. ) GO TO 4
	RETURN
4	D(I) = A(II) / B(II)
	EIG(I) = D(I)
10	II = II + N1 - I
	DO 30 I=1,N
	DO 20 J=1,N
20	X( I, J ) = 0.
30	X( I, I ) = 1.
	IF ( N .EQ. 1 ) RETURN
!
!	INITIALIZE SWEEP COUNTER AND BEGIN ITERATION
!
	NSWEEP = 0
	NR = N - 1
40	NSWEEP = NSWEEP + 1
!
!	CHECK IF PRESENT OFF-DIAGONAL ELEMENT IS LARGE ENOUGH TO REQUIRE
!	ZONING
!
	EPS = float(NSWEEP**2) /10000.
	DO 210 J=1,NR
	JP1 = J + 1
	JM1 = J - 1
	LJK = JM1 * N - JM1 * J / 2
	JJ = LJK + J
	DO 210 K=JP1,N
	KP1 = K + 1
	KM1 = K - 1
	JK = LJK + K
	KK = KM1 * N - KM1 * K / 2 + K
	EPTOLA = ( A(JK) * A(JK) ) / ( A(JJ) * A(KK) )
	EPTOLB = ( B(JK) * B(JK) ) / ( B(JJ) * B(KK) )
	IF ( ( EPTOLA .LT. EPS ) .AND. ( EPTOLB .LT. EPS ) ) GO TO 210
!
!	IF ZEROING IS REQUIRED, CALCULATE THE ROTATION MATRIX ELEMENTS CA
!	AND CG
!
	AKK = A(KK) * B(JK) - B(KK) * A(JK)
	AJJ = A(JJ) * B(JK) - B(JJ) * A(JK)
	AB = A(JJ) * B(KK) - A(KK) * B(JJ)
	CHECK = ( AB * AB + 4. * AKK * AJJ ) / 4.
	IF ( CHECK ) 50, 60, 60
50	CONTINUE
	RETURN
60	SQCH = SQRT( CHECK )
	D1 = AB / 2. + SQCH
	D2 = AB / 2. - SQCH
	DEN = D1
	IF ( ABS(D2) .GT. ABS(D1) ) DEN = D2
	IF ( DEN ) 80, 70, 80
70	CA = 0.
	CG = - A(JK) / A(KK)
	GO TO 90
80	CA = AKK / DEN
	CG = - AJJ / DEN
!
!	PERFORM THE GENERALIZED ROTATION TO ZERO THE PRESENT OFF-DIAGONAL
!	ELEMENT
!
90	IF ( N-2 ) 100, 190, 100
100	IF ( JM1 - 1 ) 130, 110, 110
110	DO 120 I=1,JM1
	IM1 = I - 1
	IJ = IM1 * N - IM1 * I / 2 + J
	IK = IM1 * N - IM1 * I / 2 + K
	AJ = A(IJ)
	BJ = B(IJ)
	AK = A(IK)
	BK = B(IK)
	A(IJ) = AJ + CG * AK
	B(IJ) = BJ + CG * BK
	A(IK) = AK + CA * AJ
120	B(IK) = BK + CA * BJ
130	IF ( KP1 - N ) 140, 140, 160
140	LJI = JM1 * N - JM1 * J / 2
	LKI = KM1 * N - KM1 * K / 2
	DO 150 I=KP1,N
	JI = LJI + I
	KI = LKI + I
	AJ = A(JI)
	BJ = B(JI)
	AK = A(KI)
	BK = B(KI)
	A(JI) = AJ + CG * AK
	B(JI) = BJ + CG * BK
	A(KI) = AK + CA * AJ
150	B(KI) = BK + CA * BJ
160	IF ( JP1 - KM1 ) 170, 170, 190
170	LJI = JM1 * N - JM1 * J / 2
	DO 180 I=JP1,KM1
	JI = LJI + I
	IM1= I - 1
	IK = IM1 * N - IM1 * I / 2 + K
	AJ = A(JI)
	BJ = B(JI)
	AK = A(IK)
	BK = B(IK)
	A(JI) = AJ + CG * AK
	B(JI) = BJ + CG * BK
	A(IK) = AK + CA * AJ
180	B(IK) = BK + CA * BJ
190	AK = A(KK)
	BK = B(KK)
	A(KK) = AK + 2. * CA * A(JK) + CA * CA * A(JJ)
	B(KK) = BK + 2. * CA * B(JK) + CA * CA * B(JJ)
	A(JJ) = A(JJ) + 2. * CG * A(JK) + CG * CG * AK
	B(JJ) = B(JJ) + 2. * CG * B(JK) + CG * CG * BK
	A(JK) = 0.
	B(JK) = 0.
!
!	UPDATE THE EIGENVECTOR MATRIX AFTER EACH ROTATION
!
	DO 200 I=1,N
	XJ = X( I, J )
	XK = X( I, K )
	X( I, J ) = XJ + CG * XK
200	X( I, K ) = XK + CA * XJ
210	CONTINUE
!
!	UPDATE THE EIGENVALUES AFTER EACH SWEEP
!
	II = 1
	DO 220 I=1,N
	IF ( A(II) .GT. 0. .AND. B(II) .GT. 0. ) GO TO 215
	RETURN
215	EIG(I) = A(II) / B(II)
220	II = II + N1 - I
!
!	CHECK FOR CONVERGENCE
!
230	DO 240 I=1,N
	TOL = RTOL * D(I)
	DIF = ABS( EIG(I) - D(I) )
	IF ( DIF .GT. TOL ) GO TO 280
240	CONTINUE
!
!	CHECK ALL OFF-DIAGONAL ELEMENTS TO SEE IF ANOTHER SWEEP IS
!	REQUIRED
!
	EPS = RTOL ** 2
	DO 250 J=1,NR
	JM1 = J - 1
	JP1 = J + 1
	LJK = JM1 * N - JM1 * J / 2
	JJ = LJK + J
	DO 250 K=JP1,N
	KM1 = K - 1
	JK = LJK + K
	KK = KM1 * N - KM1 * K / 2 + K
	EPSA = ( A(JK) * A(JK) ) / ( A(JJ) + A(KK) )
	EPSB = ( B(JK) * B(JK) ) / ( B(JJ) + B(KK) )
	IF ( ( EPSA .LT. EPS ) .AND. ( EPSB .LT. EPS ) ) GO TO 250
	GO TO 280
250	CONTINUE
!
!	FILL OUT BOTTOM TRIANGLE OF RESULTANT MATRICES AND SCALE
!	EIGENVECTORS
!
255	II = 1
	DO 275 I=1,N
	BB = SQRT ( B(II) )
	DO 270 K=1,N
270	X( K, I ) = X( K, I ) / BB
275	II = II + N1 - I
	RETURN
!
!	UPDATE D MATRIX AND START NEW SWEEP, IF ALLOWED
!
280	DO 290 I=1,N
290	D(I) = EIG(I)
	IF ( NSWEEP .LT. NSMAX ) GO TO 40
	GO TO 255
!2000	FORMAT ( 'SWEEP NUMBER IN * JACOBI * = ', I4 )
!2010	FORMAT ( / 6E20.12 )
!2020	FORMAT ( '*** ERROR  SOLUTION STOP ' /
!     1	'MATRICES NOT POSITIVE DEFINITE ' /
!     2	' II =', I4, ' A(II) = ', E20.12, ' B(II) =', E20.12 )
!2030	FORMAT ( 'CURRENT EIGENVALUES IN * JACOBI * ARE '/ )
	END
!